@@ -1,4 +1,4 @@
-from .dynamodb_table import DynamoDBTable
+from .dynamodb_table import DynamoDBTable, ItemNotFound
 from .nba_games import NbaGamesTable
 from .nba_players_stats import NbaPlayersStats, NbaPlayerPerformances
 from .nba_players import NbaPlayersTable
